======================================
``psyclone.psyir.nodes.psy_data_node``
======================================

.. automodule:: psyclone.psyir.nodes.psy_data_node

   .. contents::
      :local:

.. currentmodule:: psyclone.psyir.nodes.psy_data_node


Classes
=======

- :py:class:`PSyDataNode`:
  This class can be inserted into a schedule to instrument a set of nodes.


.. autoclass:: PSyDataNode
   :members:

   .. rubric:: Inheritance
   .. inheritance-diagram:: PSyDataNode
      :parts: 1
